@@ -5,6 +5,7 @@ from fastapi._compat import (
     ModelField,
     Undefined,
     _get_model_config,
+    get_cached_model_fields,
     get_model_fields,
     is_bytes_sequence_annotation,
     is_scalar_field,
@@ -79,6 +80,51 @@ def test_complex():
     assert response2.json() == [1, 2]
 
 
+@needs_pydanticv2
+def test_propagates_pydantic2_model_config():
+    app = FastAPI()
+
+    class Missing:
+        def __bool__(self):
+            return False
+
+    class EmbeddedModel(BaseModel):
+        model_config = ConfigDict(arbitrary_types_allowed=True)
+        value: Union[str, Missing] = Missing()
+
+    class Model(BaseModel):
+        model_config = ConfigDict(
+            arbitrary_types_allowed=True,
+        )
+        value: Union[str, Missing] = Missing()
+        embedded_model: EmbeddedModel = EmbeddedModel()
+
+    @app.post("/")
+    def foo(req: Model) -> Dict[str, Union[str, None]]:
+        return {
+            "value": req.value or None,
+            "embedded_value": req.embedded_model.value or None,
+        }
+
+    client = TestClient(app)
+
+    response = client.post("/", json={})
+    assert response.status_code == 200, response.text
+    assert response.json() == {
+        "value": None,
+        "embedded_value": None,
+    }
+
+    response2 = client.post(
+        "/", json={"value": "foo", "embedded_model": {"value": "bar"}}
+    )
+    assert response2.status_code == 200, response2.text
+    assert response2.json() == {
+        "value": "foo",
+        "embedded_value": "bar",
+    }
+
+
 def test_is_bytes_sequence_annotation_union():
     # For coverage
     # TODO: in theory this would allow declaring types that could be lists of bytes
@@ -102,3 +148,18 @@ def test_is_pv1_scalar_field():
 
     fields = get_model_fields(Model)
     assert not is_scalar_field(fields[0])
+
+
+def test_get_model_fields_cached():
+    class Model(BaseModel):
+        foo: str
+
+    non_cached_fields = get_model_fields(Model)
+    non_cached_fields2 = get_model_fields(Model)
+    cached_fields = get_cached_model_fields(Model)
+    cached_fields2 = get_cached_model_fields(Model)
+    for f1, f2 in zip(cached_fields, cached_fields2):
+        assert f1 is f2
+
+    assert non_cached_fields is not non_cached_fields2
+    assert cached_fields is cached_fields2
